@@ -788,117 +788,6 @@ class ForcedPhotometryPipeline:
             plot_alertdata=plot_alertdata,
         )
 
-    def saltfit(self, snt=5, quality_checks=False, progress=True, alertfit=False):
-        """
-        Performs a saltfit
-        """
-        self.check_if_psf_data_exists()
-        import sfdmap
-        from saltfit import fit_salt
-
-        # Read info from metadata databse and update it with mwebv
-        query = database.read_database(self.cleaned_object_list, ["ra", "dec", "mwebv"])
-
-        dustmap = sfdmap.SFDMap()
-
-        objectcount = len(self.cleaned_object_list)
-
-        self.logger.info(
-            "Checking if the mwebv Milky Way dust map value is present and compute it if not."
-        )
-
-        for index, name in enumerate(tqdm(self.cleaned_object_list)):
-            ra = query["ra"][index]
-            dec = query["dec"][index]
-
-            if query["mwebv"][index] is None:
-                mwebv = dustmap.ebv(
-                    ra,
-                    dec,
-                )
-                database.update_database(name, {"mwebv": mwebv})
-
-        object_count = len(self.cleaned_object_list)
-
-        fitresults = []
-        fitted_models = []
-
-        fitresult_df = pd.DataFrame(
-            columns=[
-                "name",
-                "chisquare",
-                "ndof",
-                "red_chisq",
-                "z",
-                "t0",
-                "x0",
-                "x1",
-                "c",
-                "t0_err",
-                "x0_err",
-                "x1_err",
-                "c_err",
-                "peak_mag",
-                "peak_abs_mag",
-                "peak_abs_mag_for_comparison",
-                "peak_abs_mag_corrected",
-                "peak_abs_mag_corrected_error",
-                "z_spectro",
-                "z_precision",
-                "g_obs",
-                "r_obs",
-                "i_obs",
-                "nr_filters",
-                "obs_total",
-            ]
-        )
-
-        for index, name in enumerate(tqdm(self.cleaned_object_list)):
-            if alertfit:
-                self.logger.info(f"{name} performing SALT fit for alert photometry.")
-            else:
-                self.logger.info(f"{name} performing SALT fit for forced photometry.")
-
-            try:
-                fitresult, fitted_model = fit_salt(
-                    name=name,
-                    snt=snt,
-                    mwebv=database.read_database(name, ["mwebv"])["mwebv"][0],
-                    quality_checks=quality_checks,
-                    alertfit=alertfit,
-                )
-                fitresults.append(fitresult)
-                fitted_models.append(fitted_model)
-            except:
-                self.logger.info(f"{name} Error while fitting.")
-
-        for fitresult in fitresults:
-            if fitresult is not None:
-                results = pd.Series(fitresult, index=fitresult_df.columns)
-                fitresult_df = fitresult_df.append(results, ignore_index=True)
-
-        if alertfit:
-            salt_dataframe_path = os.path.join(SALTDATA, "SALT_FIT_alert.csv")
-        else:
-            salt_dataframe_path = os.path.join(SALTDATA, "SALT_FIT.csv")
-        fitresult_df.set_index("name", inplace=True)
-
-        # Check if entry can be updated
-        salt_dataframe = pd.read_csv(salt_dataframe_path, index_col="name")
-
-        for index, name in enumerate(self.cleaned_object_list):
-            query_old = salt_dataframe.query("name == @name")
-            query_new = fitresult_df.query("name == @name")
-            if len(query_old) == 1:
-                salt_dataframe.drop(f"{name}", inplace=True)
-            salt_dataframe = salt_dataframe.append(query_new)
-
-        salt_dataframe.to_csv(salt_dataframe_path)
-
-        self.logger.info(
-            f"{len(fitresult_df)} of {object_count} fits were performed successfully."
-        )
-
     def sendmail(self, send_to, tarball=False):
         """ """
         self.logger.info("Sending mail.")
@@ -1069,31 +958,3 @@ class ForcedPhotometryPipeline:
     def read_metadata(self):
         query = database.read_database(self.object_list)
         return query
-
-    def read_fitresults(self):
-        return_dict = {}
-        for ztf_object in self.object_list:
-            path = os.path.join(FORCEPHOTODATA, f"{ztf_object}.csv")
-            lc = pd.read_csv(path)
-            lc = calculate_magnitudes(lc, self.snt)
-            lc = lc.filter(
-                items=[
-                    "obsmjd",
-                    "ampl",
-                    "ampl.err",
-                    "mag",
-                    "mag_err",
-                    "filter",
-                    "maglim",
-                ]
-            )
-            lc.rename(
-                columns={"ampl": "flux", "ampl.err": "flux_err", "obsmjd": "mjd"},
-                inplace=True,
-            )
-            lc.sort_values(by="mjd", inplace=True)
-            lc = lc.reset_index(drop=True)
-            lc_as_dict = lc.to_dict()
-            update_dict = {ztf_object: lc_as_dict}
-            return_dict.update(update_dict)
-        return return_dict
